@@ -393,7 +393,7 @@ class CbsClient(AbstractClient):
     def DescribeDiskStoragePool(self, request):
         """本接口（DescribeDiskStoragePool）查询用户的云硬盘独享集群列表。
 
-        * 可以根据独享集群ID(CdcId)、集群区域名(zone)类型等信息来查询和过滤云硬盘独享集群详细信息，不同条件之间为与(AND)的关系，过滤信息详细请见过滤器`Filter`。
+        * 可以根据独享集群ID(CdcId)、可用区(zone)等信息来查询和过滤云硬盘独享集群详细信息，不同的过滤条件之间为与(AND)的关系，过滤信息详细请见过滤器`Filter`。
         * 如果参数为空，返回当前用户一定数量（`Limit`所指定的数量，默认为20）的云硬盘独享集群列表。
 
         :param request: Request instance for DescribeDiskStoragePool.
